==> socket.io-file-client-1.0.82.tgz: package/socket.io-file-client.js <==
(function() {
	var CHUNK_SIZE = 524288;
	var instanceCnt = 0;

	function SocketIOFileClient(socket) {
		var self = this;
		var id = instanceCnt++;	// private
		var uploadId = 0;		// private
		this.socket = socket;
		this.ev = [];
		this.sendingFiles = [];
		this.fileReaders = [];
		this.sync = false;

		this.getId = function() {
			return id;
		};
		this.getUploadId = function() {
			return uploadId++;
		}

		this.socket.once('socket.io-file::sync', function(data) {
			this.sync = true;
		});
		this.socket.emit('socket.io-file::sync', {
			id: id
		});
		
		this.socket.on('socket.io-file::' + id + '::stream', function(data) {
			self.emit('stream', data);

			if(data.uploaded >= self.sendingFiles[id].size) return;

			var stream = data.stream * CHUNK_SIZE;	// The Next block's starting position
			var newFile;		// The variable that will hold the new Block of data

			if(self.sendingFiles[id].slice) {
				newFile = self.sendingFiles[id].slice(stream, stream + Math.min(524288, (self.sendingFiles[id].size - stream)));
			}
			else if(self.sendingFiles[id].webkitSlice) {
				newFile = self.sendingFiles[id].webkitSlice(stream, stream + Math.min(524288, (self.sendingFiles[id].size - stream)));
			}
			else {
				newFile = self.sendingFiles[id].mozSlice(stream, stream + Math.min(524288, (self.sendingFiles[id].size - stream)));
			}

			self.fileReaders[id].readAsBinaryString(newFile);
		});
		this.socket.on('socket.io-file::' + id + '::complete', function(data) {
			self.emit('complete', data);
			delete self.sendingFiles[id];
		});
		this.socket.on('socket.io-file::' + id + '::abort', function(data) {
			self.emit('abort', data);
		});
		this.socket.on('socket.io-file::' + id + '::error', function(data) {
			self.emit('error', data);
		});
	}
	SocketIOFileClient.prototype.upload = function(file, options) {
		var self = this;
		var id = this.getId();
		var uploadId = this.getUploadId();
		options = options || {};
		var types = options.types || [];
		var uploadTo = options.to || '';
		var uploadData = options.data || {};

		if(!file) {
			return self.emit('error', {
				message: "No file"
			});
		}

		this.fileReaders[uploadId] = new FileReader();

		this.sendingFiles[uploadId] = file;

		this.fileReaders[uploadId].onload = function(e) {
			// check file type
			var found = false;
			for(var i = 0; i < types.length; i++) {
				if(file.type === types[i]) {
					found = true;
					break;
				}
			}

			if(types.length > 0 && !found) {
				self.emit('error', {
					message: "Type must be one of these: " + types.toString()
				});
				
				self.socket.emit('socket.io-file::abort', {
					id: self.getId(),
					name: file.name
				});
			}
			else {
				self.socket.emit('socket.io-file::stream', {
					id: self.getId(),
					name: file.name,
					data: e.target.result
				});
			}
		};

		this.socket.emit('socket.io-file::start', {
			id: self.getId(),
			name: file.name,
			size: this.sendingFiles[id].size,
			uploadTo: uploadTo,
			data: uploadData
		});

		this.emit('start');

		return uploadId;
	};
	SocketIOFileClient.prototype.on = function(evName, fn) {
		if(!this.ev[evName]) {
			this.ev[evName] = [];
		}

		this.ev[evName].push(fn);
		return this;
	};
	SocketIOFileClient.prototype.off = function(evName, fn) {
		if(typeof evName === 'undefined') {
			this.ev = [];
		}
		else if(typeof fn === 'undefined') {
			if(this.ev[evName]) {
				delete this.ev[evName]; 
			}
		}
		else {
			var evList = this.ev[evName] || [];

			for(var i = 0; i < evList.length; i++) {
				if(evList[i] === fn) {
					evList = evList.splice(i, 1);
					break;
				}
			}
		}

		return this;
	};
	SocketIOFileClient.prototype.emit = function(evName, args) {
		var evList = this.ev[evName] || [];

		for(var i = 0; i < evList.length; i++) {
			evList[i](args);
		}

		return this;
	};
	SocketIOFileClient.prototype.abort = function(id) {
		// abort all
		if(!id) {
			for(var i = 0; i < this.sendingFiles.length; i++) {
				if(this.sendingFiles[i]) {
					this.socket.emit('socket.io-file::abort', {
						name: this.sendingFiles[i].name
					});
				}
			}
		}
		else {
			if(this.sendingFiles[id]) {
				this.socket.emit('socket.io-file::abort', {
					name: this.sendingFiles[id].name
				});
			}
		}
	};
	SocketIOFileClient.prototype.destroy = function() {
		this.abort();
		
		this.off();	// remove all listeners
		this.socket.off('socket.io-file::start');
		this.socket.off('socket.io-file::stream');
		this.socket.off('socket.io-file::abort');
		this.socket.off('socket.io-file::complete');
		this.socket.off('socket.io-file::error');
		this.fileReaders = [];
		this.sendingFiles = [];
	};

	// CommonJS
	if (typeof exports === "object" && typeof module !== "undefined") {
		module.exports = SocketIOFileClient;
	}
	// RequireJS
	else if (typeof define === "function" && define.amd) {
		define(['SocketIOFileClient'], SocketIOFileClient);
	}
	// <script>
	else {
		var g;

		if (typeof window !== "undefined") {
			g = window;
		}
		else if (typeof global !== "undefined") {
			g = global;
		}
		else if (typeof self !== "undefined") {
			g = self;
		}
		else {
			// works providing we're not in "use strict";
			// needed for Java 8 Nashorn
			// see https://github.com/facebook/react/issues/3037
			g = this;
		}

		g.SocketIOFileClient = SocketIOFileClient;
	}
})();

==> socket.io-file-client-1.0.84.tgz: package/socket.io-file-client.js <==
(function() {
	var CHUNK_SIZE = 524288;
	var instanceCnt = 0;

	function SocketIOFileClient(socket) {
		var self = this;
		var id = instanceCnt++;	// private
		var uploadId = 0;		// private
		this.socket = socket;
		this.ev = [];
		this.sendingFiles = [];
		this.fileReaders = [];
		this.sync = false;

		this.getId = function() {
			return id;
		};
		this.getUploadId = function() {
			return uploadId++;
		};

		this.socket.once('socket.io-file::sync', function(data) {
			this.sync = true;
		});
		this.socket.emit('socket.io-file::sync', {
			id: id
		});
		
		this.socket.on('socket.io-file::' + id + '::' + uploadId + 'stream', function(data) {
			data.id = id;
			data.uploadId = uploadId;
			
			self.emit('stream', data);

			if(data.uploaded >= self.sendingFiles[id].size) return;

			var stream = data.stream * CHUNK_SIZE;	// The Next block's starting position
			var newFile;		// The variable that will hold the new Block of data

			if(self.sendingFiles[id].slice) {
				newFile = self.sendingFiles[id].slice(stream, stream + Math.min(524288, (self.sendingFiles[id].size - stream)));
			}
			else if(self.sendingFiles[id].webkitSlice) {
				newFile = self.sendingFiles[id].webkitSlice(stream, stream + Math.min(524288, (self.sendingFiles[id].size - stream)));
			}
			else {
				newFile = self.sendingFiles[id].mozSlice(stream, stream + Math.min(524288, (self.sendingFiles[id].size - stream)));
			}

			self.fileReaders[id].readAsBinaryString(newFile);
		});
		this.socket.on('socket.io-file::' + id + '::complete', function(data) {
			self.emit('complete', data);
			delete self.sendingFiles[id];
		});
		this.socket.on('socket.io-file::' + id + '::abort', function(data) {
			self.emit('abort', data);
		});
		this.socket.on('socket.io-file::' + id + '::error', function(data) {
			self.emit('error', data);
		});
	}
	SocketIOFileClient.prototype.upload = function(file, options) {
		var self = this;
		var id = this.getId();
		var uploadId = this.getUploadId();
		options = options || {};
		var types = options.types || [];
		var uploadTo = options.to || '';
		var uploadData = options.data || {};

		if(!file) {
			return self.emit('error', {
				message: "No file"
			});
		}

		this.fileReaders[uploadId] = new FileReader();

		this.sendingFiles[uploadId] = file;

		this.fileReaders[uploadId].onload = function(e) {
			// check file type
			var found = false;
			for(var i = 0; i < types.length; i++) {
				if(file.type === types[i]) {
					found = true;
					break;
				}
			}

			if(types.length > 0 && !found) {
				self.emit('error', {
					message: "Type must be one of these: " + types.toString()
				});
				
				self.socket.emit('socket.io-file::abort', {
					id: self.getId(),
					name: file.name
				});
			}
			else {
				self.socket.emit('socket.io-file::stream', {
					id: id,
					uploadId: uploadId, 
					name: file.name,
					data: e.target.result
				});
			}
		};

		this.socket.emit('socket.io-file::start', {
			id: id,
			uploadId: uploadId,
			name: file.name,
			size: this.sendingFiles[id].size,
			uploadTo: uploadTo,
			data: uploadData
		});

		this.emit('start');

		return uploadId;
	};
	SocketIOFileClient.prototype.on = function(evName, fn) {
		if(!this.ev[evName]) {
			this.ev[evName] = [];
		}

		this.ev[evName].push(fn);
		return this;
	};
	SocketIOFileClient.prototype.off = function(evName, fn) {
		if(typeof evName === 'undefined') {
			this.ev = [];
		}
		else if(typeof fn === 'undefined') {
			if(this.ev[evName]) {
				delete this.ev[evName]; 
			}
		}
		else {
			var evList = this.ev[evName] || [];

			for(var i = 0; i < evList.length; i++) {
				if(evList[i] === fn) {
					evList = evList.splice(i, 1);
					break;
				}
			}
		}

		return this;
	};
	SocketIOFileClient.prototype.emit = function(evName, args) {
		var evList = this.ev[evName] || [];

		for(var i = 0; i < evList.length; i++) {
			evList[i](args);
		}

		return this;
	};
	SocketIOFileClient.prototype.abort = function(id) {
		// abort all
		if(!id) {
			for(var i = 0; i < this.sendingFiles.length; i++) {
				if(this.sendingFiles[i]) {
					this.socket.emit('socket.io-file::abort', {
						name: this.sendingFiles[i].name
					});
				}
			}
		}
		else {
			if(this.sendingFiles[id]) {
				this.socket.emit('socket.io-file::abort', {
					name: this.sendingFiles[id].name
				});
			}
		}
	};
	SocketIOFileClient.prototype.destroy = function() {
		this.abort();
		
		this.off();	// remove all listeners
		this.socket.off('socket.io-file::start');
		this.socket.off('socket.io-file::stream');
		this.socket.off('socket.io-file::abort');
		this.socket.off('socket.io-file::complete');
		this.socket.off('socket.io-file::error');
		this.fileReaders = [];
		this.sendingFiles = [];
	};

	// CommonJS
	if (typeof exports === "object" && typeof module !== "undefined") {
		module.exports = SocketIOFileClient;
	}
	// RequireJS
	else if (typeof define === "function" && define.amd) {
		define(['SocketIOFileClient'], SocketIOFileClient);
	}
	// <script>
	else {
		var g;

		if (typeof window !== "undefined") {
			g = window;
		}
		else if (typeof global !== "undefined") {
			g = global;
		}
		else if (typeof self !== "undefined") {
			g = self;
		}
		else {
			// works providing we're not in "use strict";
			// needed for Java 8 Nashorn
			// see https://github.com/facebook/react/issues/3037
			g = this;
		}

		g.SocketIOFileClient = SocketIOFileClient;
	}
})();
